Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddFlash ¶
AddFlash adds a flash message to the session for display at the next page render. The key groups together messages of a similar category and will be interpeted by the template. It's common to use keys like "success", "info", "warning", and "error" which map to CSS classes. Value is the string to be displayed.
func Flash ¶
Flash grabs the flash messages from the session and removes them so they'll only be rendered once.
func NewMiddleware ¶
NewMiddleware returns middleware that decodes the session from the request and adds it to the request context, guaranteeing it'll be there and making gorilla/sessions easier to work with.
Types ¶
Click to show internal directories.
Click to hide internal directories.